@@ -1,5 +1,5 @@
 /*!
- * MorphSVGPlugin 3.3.4
+ * MorphSVGPlugin 3.5.1
  * https://greensock.com
  *
  * @license Copyright 2008-2020, GreenSock. All rights reserved.
@@ -19,6 +19,9 @@ var gsap,
     PluginClass,
     _getGSAP = function _getGSAP() {
   return gsap || typeof window !== "undefined" && (gsap = window.gsap) && gsap.registerPlugin && gsap;
+},
+    _isFunction = function _isFunction(value) {
+  return typeof value === "function";
 },
     _atan2 = Math.atan2,
     _cos = Math.cos,
@@ -750,8 +753,10 @@ _populateSmoothData = function _populateSmoothData(rawPath, tolerance) {
 };
 
 export var MorphSVGPlugin = {
-  version: "3.3.4",
+  version: "3.5.1",
   name: "morphSVG",
+  rawVars: 1,
+  // otherwise "render" would be interpreted as a function-based value.
   register: function register(core, Plugin) {
     gsap = core;
     PluginClass = Plugin;
@@ -767,35 +772,28 @@ export var MorphSVGPlugin = {
       return false;
     }
 
-    (typeof value === "string" || value.getBBox || value[0]) && (value = {
-      shape: value
-    });
+    _isFunction(value) && (value = value.call(tween, index, target, targets));
+    var type, p, pt, shape, isPoly, shapeIndex, map, startSmooth, endSmooth, start, end, i, j, l, startSeg, endSeg, precompiled, sData, eData, originFactors, useRotation, offset;
+
+    if (typeof value === "string" || value.getBBox || value[0]) {
+      value = {
+        shape: value
+      };
+    } else if (typeof value === "object") {
+      // if there are any function-based values, parse them here (and make a copy of the object so we're not modifying the original)
+      type = {};
+
+      for (p in value) {
+        type[p] = _isFunction(value[p]) && p !== "render" ? value[p].call(tween, index, target, targets) : value[p];
+      }
+
+      value = type;
+    }
+
     var cs = target.nodeType ? window.getComputedStyle(target) : {},
         fill = cs.fill + "",
         fillSafe = !(fill === "none" || (fill.match(_numExp) || [])[3] === "0" || cs.fillRule === "evenodd"),
-        origins = (value.origin || "50 50").split(","),
-        type,
-        p,
-        pt,
-        shape,
-        isPoly,
-        shapeIndex,
-        map,
-        startSmooth,
-        endSmooth,
-        start,
-        end,
-        i,
-        j,
-        l,
-        startSeg,
-        endSeg,
-        precompiled,
-        sData,
-        eData,
-        originFactors,
-        useRotation,
-        offset;
+        origins = (value.origin || "50 50").split(",");
     type = (target.nodeName + "").toUpperCase();
     isPoly = type === "POLYLINE" || type === "POLYGON";
 
@@ -807,7 +805,7 @@ export var MorphSVGPlugin = {
 
     p = type === "PATH" ? "d" : "points";
 
-    if (!value.prop && typeof target.setAttribute !== "function") {
+    if (!value.prop && !_isFunction(target.setAttribute)) {
       return false;
     }
 
