@@ -1,5 +1,5 @@
 /*!
- * SplitText: 3.5.1
+ * SplitText: 3.3.4
  * https://greensock.com
  *
  * @license Copyright 2008-2020, GreenSock. All rights reserved.
@@ -100,7 +100,7 @@ let _doc, _win, _coreInitted,
 			borderLeftAndRight = _getStyleAsNumber("borderLeftWidth", cs) + _getStyleAsNumber("borderRightWidth", cs),
 			padTopAndBottom = _getStyleAsNumber("paddingTop", cs) + _getStyleAsNumber("paddingBottom", cs),
 			padLeftAndRight = _getStyleAsNumber("paddingLeft", cs) + _getStyleAsNumber("paddingRight", cs),
-			lineThreshold = _getStyleAsNumber("fontSize", cs) * (vars.lineThreshold || 0.2),
+			lineThreshold = _getStyleAsNumber("fontSize", cs) * 0.2,
 			textAlign = cs.textAlign,
 			charArray = [],
 			wordArray = [],
@@ -167,7 +167,9 @@ let _doc, _win, _coreInitted,
 			isChild = (node.parentNode === element);
 			if (node.nodeName === "BR") {
 				if (lines || absolute) {
-					node.parentNode && node.parentNode.removeChild(node);
+					if (node.parentNode) {
+						node.parentNode.removeChild(node);
+					}
 					nodes.splice(i--, 1);
 					l--;
 				} else if (!words) {
@@ -214,7 +216,9 @@ let _doc, _win, _coreInitted,
 					if (node.parentNode._parent) {
 						node.parentNode._parent.appendChild(node);
 					}
-					offset && node.parentNode.appendChild(_doc.createTextNode(" "));
+					if (offset) {
+						node.parentNode.appendChild(_doc.createTextNode(" "));
+					}
 					if (tag === "span") {
 						node.style.display = "inline"; //so that word breaks are honored properly.
 					}
@@ -264,7 +268,9 @@ let _doc, _win, _coreInitted,
 					if (curLine[j].nodeName !== "BR") {
 						node = curLine[j];
 						lineNode.appendChild(node);
-						addWordSpaces && node._wordEnd && lineNode.appendChild(_doc.createTextNode(" "));
+						if (addWordSpaces && node._wordEnd) {
+							lineNode.appendChild(_doc.createTextNode(" "));
+						}
 						if (absolute) {
 							if (j === 0) {
 								lineNode.style.top = (node._y) + "px";
@@ -408,18 +414,24 @@ let _doc, _win, _coreInitted,
 export class SplitText {
 
 	constructor(element, vars) {
-		_coreInitted || _initCore();
+		if (!_coreInitted) {
+			_initCore();
+		}
 		this.elements = _toArray(element);
 		this.chars = [];
 		this.words = [];
 		this.lines = [];
 		this._originals = [];
 		this.vars = vars || {};
-		_bonusValidated && this.split(vars);
+		if (_bonusValidated) {
+			this.split(vars);
+		}
 	}
 
 	split(vars) {
-		this.isSplit && this.revert();
+		if (this.isSplit) {
+			this.revert();
+		}
 		this.vars = vars = vars || this.vars;
 		this._originals.length = this.chars.length = this.words.length = this.lines.length = 0;
 		let i = this.elements.length,
@@ -462,6 +474,6 @@ export class SplitText {
 
 }
 
-SplitText.version = "3.5.1";
+SplitText.version = "3.3.4";
 
 export { SplitText as default };
\ No newline at end of file
